==> nuntio_hera-0.0.4.tar.gz: lib/hera_ui/components/nuntio_text_field.dart <==
import 'package:flutter/cupertino.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import '../models.dart';
import 'nuntio_button.dart';
import 'text_field_decoration.dart';

class NuntioTextField extends StatefulWidget {
  final String? label;
  final String? hint;
  final TextInputType? textInputType;
  final TextEditingController? controller;
  final HeraTextStyle nuntioTextStyle;
  final HeraStyle nuntioStyle;
  final HeraColor nuntioColor;
  final bool? obscureText;
  final TextInputAction? textInputAction;
  final Function(String)? onSubmitted;
  final Function(String)? onChanged;
  final IconData? prefix;
  final Brightness? brightness;
  final FocusNode? focusNode;
  final EdgeInsets? scrollPadding;
  final Iterable<String>? autofillHints;
  final EdgeInsets padding;

  NuntioTextField({
    required this.nuntioTextStyle,
    required this.nuntioStyle,
    required this.nuntioColor,
    this.padding = const EdgeInsets.only(bottom: 10),
    this.controller,
    this.label,
    this.hint,
    this.textInputType,
    this.obscureText,
    this.textInputAction,
    this.onSubmitted,
    this.onChanged,
    this.prefix,
    this.brightness,
    this.focusNode,
    this.scrollPadding,
    this.autofillHints,
  });

  @override
  State<NuntioTextField> createState() => _NuntioTextFieldState(
        activeColor: nuntioColor.primaryColor.withOpacity(0.7),
        inactiveColor: nuntioStyle.borderColor,
        currentColor: nuntioStyle.borderColor,
        iconColor: nuntioColor.labelColor.withOpacity(0.3),
        focusNode: focusNode ?? FocusNode(),
      );
}

class _NuntioTextFieldState extends State<NuntioTextField> {
  final FocusNode focusNode;
  bool isActive = false;
  Color activeColor;
  Color inactiveColor;
  Color currentColor;
  Color iconColor;

  _NuntioTextFieldState({
    required this.activeColor,
    required this.inactiveColor,
    required this.currentColor,
    required this.iconColor,
    required this.focusNode,
  });

  @override
  void initState() {
    focusNode.addListener(() {
      if (focusNode.hasFocus) {
        setState(() {
          currentColor = activeColor;

          isActive = true;
        });
      } else {
        setState(() {
          currentColor = inactiveColor;
          isActive = false;
        });
      }
    });
    return super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: widget.padding,
      child: Column(
        children: [
          if (widget.label != null && widget.label != "")
            Padding(
              padding: EdgeInsets.only(bottom: 7),
              child: Align(
                alignment: Alignment.centerLeft,
                child: Text(
                  widget.label!,
                  style: widget.nuntioTextStyle.labelStyle,
                  textAlign: TextAlign.left,
                ),
              ),
            ),
          SizedBox(
            height: widget.nuntioStyle.buttonHeight,
            width: widget.nuntioStyle.buttonWidth,
            child: CupertinoTextField(
              autocorrect: true,
              autofillHints: widget.autofillHints,
              focusNode: focusNode,
              scrollPadding: widget.scrollPadding ?? EdgeInsets.only(bottom: 40),
              style: TextStyle(
                  color: isActive
                      ? widget.brightness == Brightness.dark
                          ? white
                          : black
                      : widget.brightness == Brightness.dark
                          ? Color(0xff8E8E93)
                          : withDarken(currentColor, .5)),
              obscureText: widget.obscureText ?? false,
              placeholderStyle:
                  TextStyle(color: widget.nuntioColor.labelColor.withOpacity(0.3)),
              onTap: () {},
              prefix: widget.prefix != null
                  ? Padding(
                      padding: const EdgeInsets.only(left: 12, top: 3, right: 5),
                      child: FaIcon(
                        widget.prefix,
                        size: 15,
                        color: focusNode.hasFocus ? activeColor : iconColor,
                      ),
                    )
                  : null,
              decoration: textFieldDecoration(
                  border: Border.all(
                    color: currentColor,
                    width: 1,
                  ),
                  color: widget.nuntioStyle.textFieldColor,
                  isActive: isActive,
                  activeColor: currentColor,
                  blurRadius: widget.nuntioStyle.blurRadius,
                  spreadRadius: widget.nuntioStyle.spreadRadius),
              textInputAction: widget.textInputAction,
              // Moves focus to next.
              controller: widget.controller,
              placeholder: widget.hint,
              keyboardType: widget.textInputType,
              onSubmitted: widget.onSubmitted,
              onChanged: widget.onChanged,
            ),
          ),
        ],
      ),
    );
  }
}

==> nuntio_hera-0.0.36.tar.gz: lib/hera_ui/components/nuntio_text_field.dart <==
import 'package:flutter/cupertino.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import '../models.dart';
import 'nuntio_button.dart';
import 'text_field_decoration.dart';

class NuntioTextField extends StatefulWidget {
  final String? label;
  final String? hint;
  final TextInputType? textInputType;
  final TextEditingController? controller;
  final HeraTextStyle? nuntioTextStyle;
  final HeraStyle? nuntioStyle;
  final HeraColor? nuntioColor;
  final bool? obscureText;
  final TextInputAction? textInputAction;
  final Function(String)? onSubmitted;
  final Function(String)? onChanged;
  final IconData? prefix;
  final Brightness? brightness;
  final FocusNode? focusNode;
  final EdgeInsets? scrollPadding;
  final Iterable<String>? autofillHints;
  final EdgeInsets padding;

  NuntioTextField({
    this.nuntioTextStyle,
     this.nuntioStyle,
     this.nuntioColor,
    this.padding = const EdgeInsets.only(bottom: 10),
    this.controller,
    this.label,
    this.hint,
    this.textInputType,
    this.obscureText,
    this.textInputAction,
    this.onSubmitted,
    this.onChanged,
    this.prefix,
    this.brightness,
    this.focusNode,
    this.scrollPadding,
    this.autofillHints,
  });

  @override
  State<NuntioTextField> createState() => _NuntioTextFieldState(
        activeColor: (nuntioColor?.primaryColor ?? CupertinoColors.systemBlue).withOpacity(0.7),
        inactiveColor: nuntioStyle?.borderColor ?? CupertinoColors.systemGrey5,
        currentColor: nuntioStyle?.borderColor ?? CupertinoColors.systemGrey5,
        iconColor: (nuntioColor?.labelColor ?? CupertinoColors.systemGrey).withOpacity(0.3),
        focusNode: focusNode ?? FocusNode(),
      );
}

class _NuntioTextFieldState extends State<NuntioTextField> {
  final FocusNode focusNode;
  bool isActive = false;
  Color activeColor;
  Color inactiveColor;
  Color currentColor;
  Color iconColor;

  _NuntioTextFieldState({
    required this.activeColor,
    required this.inactiveColor,
    required this.currentColor,
    required this.iconColor,
    required this.focusNode,
  });

  @override
  void initState() {
    focusNode.addListener(() {
      if (focusNode.hasFocus) {
        setState(() {
          currentColor = activeColor;

          isActive = true;
        });
      } else {
        setState(() {
          currentColor = inactiveColor;
          isActive = false;
        });
      }
    });
    return super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: widget.padding,
      child: Column(
        children: [
          if (widget.label != null && widget.label != "")
            Padding(
              padding: EdgeInsets.only(bottom: 7),
              child: Align(
                alignment: Alignment.centerLeft,
                child: Text(
                  widget.label!,
                  style: widget.nuntioTextStyle?.labelStyle,
                  textAlign: TextAlign.left,
                ),
              ),
            ),
          SizedBox(
            height: widget.nuntioStyle?.buttonHeight,
            width: widget.nuntioStyle?.buttonWidth,
            child: CupertinoTextField(
              autocorrect: true,
              autofillHints: widget.autofillHints,
              focusNode: focusNode,
              scrollPadding: widget.scrollPadding ?? EdgeInsets.only(bottom: 40),
              style: TextStyle(
                  color: isActive
                      ? widget.brightness == Brightness.dark
                          ? white
                          : black
                      : widget.brightness == Brightness.dark
                          ? Color(0xff8E8E93)
                          : withDarken(currentColor, .5)),
              obscureText: widget.obscureText ?? false,
              placeholderStyle:
                  TextStyle(color: widget.nuntioColor?.labelColor.withOpacity(0.3)),
              onTap: () {},
              prefix: widget.prefix != null
                  ? Padding(
                      padding: const EdgeInsets.only(left: 12, top: 3, right: 5),
                      child: FaIcon(
                        widget.prefix,
                        size: 15,
                        color: focusNode.hasFocus ? activeColor : iconColor,
                      ),
                    )
                  : null,
              decoration: textFieldDecoration(
                  border: Border.all(
                    color: currentColor,
                    width: 1,
                  ),
                  color: widget.nuntioStyle?.textFieldColor,
                  isActive: isActive,
                  activeColor: currentColor,
                  blurRadius: widget.nuntioStyle?.blurRadius,
                  spreadRadius: widget.nuntioStyle?.spreadRadius),
              textInputAction: widget.textInputAction,
              // Moves focus to next.
              controller: widget.controller,
              placeholder: widget.hint,
              keyboardType: widget.textInputType,
              onSubmitted: widget.onSubmitted,
              onChanged: widget.onChanged,
            ),
          ),
        ],
      ),
    );
  }
}
